"""
Description:

    A Class for undersanding Spelling Mistakes

"""
import re

try:
    from interfaces import ISpellingMistake
except:
    class ISpellingMistake: pass

def escape(text):
    """
    Escapes characters with a \
    Mostly to catch single quotes breaking js code
    """
    return re.sub("'","\\'",text)

class SpellingMistake:
    """
    A spelling mistake object giving access to appropriate attributes
    provided by a spell checker
    """

    __implements__ = ISpellingMistake
    __allow_access_to_unprotected_subobjects__ = 1

    def __init__(self, word, line_count, line_offset, replace_values=()):
        self.word = word
        self.line_count = line_count
        self.line_offset = line_offset
        self.replace_values = replace_values

    def misspelled_word(self):
        """
        The word identified as being misspelled
        """
        return self.word

    def escaped_word(self):
        """
        The word identified as being misspelled escaped
        """
        return escape(self.word)

    def line(self):
        """
        The line in text body where the bad word occurs
        Numbered in sequence from the start of the text (0)
        """
        return self.line_count

    def offset(self):
        """
        A character offest in the line where the word occurs;
        provided by the speller
        """
        return self.line_offset

    def values(self):
        """
        A list of possible replacement words as suggested by the speller
        """
        return self.replace_values

    def __str__(self):
        return self.word

    def __repr__(self):
        return "%s %s"%(self.__class__.__name__, self.word)

class InputBuffer:

    def __init__(self, text):
        self.text = text.split('\n')

    def __getitem__(self, i):
        return self.text[i]
