# -*- coding: latin1 -*-

"""
Set defaults for initialising a speller
These are used when a speller is chosen, they can be over-ridden
for each instance

- speller
  name of the binary to call

- binpath
  path to the binary

- language
  default language from the list below

- languages
  list of valid languages the speller knows about
  this is system dependent, what wordlist have been installed?
  this can be set as none if there is no choice

- languagesw
  the switch the command uses for setting the language
  if this is empty, no language will be specified

- encoding
  the default char-encoding from the following list

- encodings
  list of encodings the speller understands
  this can be set as none if there is no choice
  switch to set the encoding

- encodingsw
  switch used to set the encoding
  if this is empty, no encoding will be attempted

- pipesw
  the switch setting the speller into pipe mode

- switches
  other default switches used, these are additional
  to swicthes defined here

- canreload
  True/False whether a personal wordlist can be read
  back by the speller

- wordlistsw
  switch used to specifiy an included wordlist

"""
# Defaults for aspell
#
# aspell is hosted on sourceforge
# http://aspell.sourceforge.net/
#
# you can check the dictionaries available with the command
# "aspell dump dicts"
#
# Listed here are all the dictionaries, languages and encodings
# known for aspell v0.50.5, delete or amend as required
#
# Known problems with aspell
#
# 1. v0.50.3 gets confused by the "@" sign in -H mode and
#    refuses to spell-check documents
#    Solution: upgrade to v0.50.5 or later

#
# to disable switches passed from Zope and
# to enable a local config file (untested)
# - set switches to ''
#   applies to dictsw, languagesw, encodingsw
#

defs = {
   'speller': 'aspell',
   'binpath': '/usr/bin',
   'dict': 'en',
   'dicts': {
     'af': 'Afrikaans',
     'be': 'Belarusian',
     'bg': 'Bulgarian',
     'bn': 'Bengali',
     'br': 'Breton',
     'ca': 'Catalan',
     'cs': 'Czech',
     'cy': 'Welsh',
     'da': 'Danish',
     'de': 'German',
     'el': 'Greek',
     'en': 'English',
     'eo': 'Esperanto',
     'es': 'Spanish',
     'fo': 'Faroese',
     'fr': 'French',
     'ga': 'Irish',
     'gd': 'Scots Gaelic',
     'gl': 'Gallegan',
     'gv': 'Manx Gaelic',
     'he': 'Hebrew',
     'hr': 'Croatian',
     'ia': 'Interlingua',
     'id': 'Indonesian',
     'is': 'Icelandic',
     'it': 'Italian',
     'mi': 'Maori',
     'mk': 'Macedonian',
     'ms': 'Malay',
     'mt': 'Maltese',
     'nb': 'Norwegian Bokmal',
     'nl': 'Dutch',
     'nn': 'Norwegian Nynorsk',
     'pl': 'Polish',
     'pt': 'Português',
     'pt_BR': 'Português do Brasil',
     'ro': 'Romanian',
     'ru': 'Russian',
     'sk': 'Slovak',
     'sl': 'Slovenian',
     'sv': 'Swedish',
     'sw': 'Swahili',
     'tn': 'Tswana',
     'tr': 'Turkish',
     'uk': 'Ukrainian',
     'wa': 'Walloon',
     'zu': 'Zulu'
   },
   'dictsw': '-d',
   'language': 'en',
   'languages': {
     'aa': 'Afar',
     'af': 'Afrikaans',
     'ak': 'Akan',
     'am': 'Amharic',
     'ar': 'Arabic',
     'as': 'Assamese',
     'ast': 'Asturian',
     'av': 'Avar',
     'ay': 'Aymara',
     'az': 'Azerbaijani',
     'ba': 'Bashkir',
     'be': 'Belarusian',
     'bg': 'Bulgarian',
     'bh': 'Bihari',
     'bm': 'Bambara',
     'bn': 'Bengali',
     'bo': 'Tibetan',
     'br': 'Breton',
     'bs': 'Bosnian',
     'ca': 'Catalan',
     'ce': 'Chechen',
     'ceb': 'Cebuano',
     'ch': 'Chamorro',
     'co': 'Corsican',
     'cs': 'Czech',
     'cv': 'Chuvash',
     'cy': 'Welsh',
     'da': 'Danish',
     'de': 'German',
     'ee': 'Ewe',
     'el': 'Greek',
     'en': 'English',
     'eo': 'Esperanto',
     'es': 'Spanish',
     'et': 'Estonian',
     'eu': 'Basque',
     'fa': 'Persian',
     'ff': 'Fulah',
     'fi': 'Finnish',
     'fj': 'Fijian',
     'fo': 'Faroese',
     'fr': 'French',
     'fy': 'Frisian',
     'ga': 'Irish',
     'gd': 'Scots Gaelic',
     'gl': 'Gallegan',
     'gn': 'Guarani',
     'gu': 'Gujarati',
     'gv': 'Manx Gaelic',
     'ha': 'Hausa',
     'haw': 'Hawaiian',
     'he': 'Hebrew',
     'hi': 'Hindi',
     'ho': 'Hiri',
     'hr': 'Croatian',
     'hsb': 'Upper Sorbian',
     'ht': 'Haitian Creole',
     'hu': 'Hungarian',
     'hy': 'Armenian',
     'hz': 'Herero',
     'ia': 'Interlingua',
     'id': 'Indonesian',
     'ig': 'Igbo',
     'ii': 'Sichuan Yi',
     'io': 'Ido',
     'is': 'Icelandic',
     'it': 'Italian',
     'jbo': 'Lojban',
     'jv': 'Javanese',
     'ka': 'Georgian',
     'kg': 'Kongo',
     'ki': 'Kikuyu',
     'kj': 'Kwanyama',
     'kk': 'Kazakh',
     'kn': 'Kannada',
     'kr': 'Kanuri',
     'ks': 'Kashmiri',
     'ku': 'Kurdish',
     'kv': 'Komi',
     'kw': 'Cornish',
     'ky': 'Kirghiz',
     'la': 'Latin',
     'lb': 'Luxembourgish',
     'lg': 'Ganda',
     'li': 'Limburgian',
     'ln': 'Lingala',
     'lt': 'Lithuanian',
     'lu': 'Luba-Katanga',
     'lv': 'Latvian',
     'mg': 'Malagasy',
     'mi': 'Maori',
     'mk': 'Macedonian',
     'ml': 'Malayalam',
     'mn': 'Mongolian',
     'mo': 'Moldavian',
     'mr': 'Marathi',
     'ms': 'Malay',
     'mt': 'Maltese',
     'my': 'Burmese',
     'nb': 'Norwegian Bokmal',
     'nd': 'North Ndebele',
     'nds': 'Low Saxon',
     'ne': 'Nepali',
     'ng': 'Ndonga',
     'nl': 'Dutch',
     'nn': 'Norwegian Nynorsk',
     'nr': 'South Ndebele',
     'nv': 'Navajo',
     'ny': 'Nyanja',
     'oc': 'Occitan',
     'om': 'Oromo',
     'or': 'Oriya',
     'os': 'Ossetic',
     'pa': 'Punjabi',
     'pl': 'Polish',
     'ps': 'Pushto',
     'pt': 'Português',
     'pt_BR': 'Português do Brasil',
     'qu': 'Quechua',
     'rn': 'Rundi',
     'ro': 'Romanian',
     'ru': 'Russian',
     'rw': 'Kinyarwanda',
     'sc': 'Sardinian',
     'sd': 'Sindhi',
     'sg': 'Sango',
     'si': 'Sinhalese',
     'sk': 'Slovak',
     'sl': 'Slovenian',
     'sm': 'Samoan',
     'sn': 'Shona',
     'so': 'Somali',
     'sq': 'Albanian',
     'sr': 'Serbian',
     'ss': 'Swati',
     'st': 'Southern Sotho',
     'su': 'Sundanese',
     'sv': 'Swedish',
     'sw': 'Swahili',
     'ta': 'Tamil',
     'te': 'Telugu',
     'tet': 'Tetum',
     'tg': 'Tajik',
     'ti': 'Tigrinya',
     'tk': 'Turkmen',
     'tl': 'Tagalog',
     'tn': 'Tswana',
     'to': 'Tonga',
     'tpi': 'Tok',
     'tr': 'Turkish',
     'ts': 'Tsonga',
     'tt': 'Tatar',
     'tw': 'Twi',
     'ty': 'Tahitian',
     'ug': 'Uighur',
     'uk': 'Ukrainian',
     'ur': 'Urdu',
     'uz': 'Uzbek',
     've': 'Venda',
     'vi': 'Vietnamese',
     'wa': 'Walloon',
     'wo': 'Wolof',
     'xh': 'Xhosa',
     'yi': 'Yiddish',
     'yo': 'Yoruba',
     'za': 'Zhuang',
     'zu': 'Zulu'
   },
   'languagesw': '--lang=',
   'encoding': 'utf-8',
   'encodings': (
     'utf-8',
     'iso-8859-1',
     'iso-8859-2',
     'iso-8859-3',
     'iso-8859-4',
     'iso-8859-5',
     'iso-8859-6',
     'iso-8859-7',
     'iso-8859-8',
     'iso-8859-9',
     'iso-8859-10',
     'iso-8859-11',
     'iso-8859-13',
     'iso-8859-14',
     'iso-8859-15',
     'koi8-f',
     'koi8-r',
     'koi8-u',
     'viscii',
     'cp1250',
     'cp1251',
     'cp1252',
     'cp1253',
     'cp1254',
     'cp1255',
     'cp1256',
     'cp1257',
     'cp1258'
   ),
   'encodingsw': '--encoding=',
   'pipesw': '-a',
   'switches': '-H', # sets HTML mode
   'canreload': 'YES',
   'wordlistsw': '-p',
}
