from Interface import Base as Interface

class ISpellCheckTool(Interface):

    def manageSpeller():
        """
        Update speller controls
        The ZMI manage function that maintains the control
        settings (command line switches and options) for your selected speller
        """

    def manageWordlist():
        """
        Manage the supplemntary Wordlist
        This should be saved on the filesystem so the speller can see it
        SysteManager can also upload or download the file outside of Zope or
        edit it directly (in ZMI)
        """

    def validSpellers():
        """
        Provide a list of available spellers
        This list is generated from speller definition files that have
        been successfully loaded by this module.
        (into dictionary 'spellers' - see above)
        """

    def spellerDefaults():
        """
        Provide a list of parameters for each available speller.
        These are picked up from speller.defs, a dictionary defined
        in a module for each speller
        """

    # Class Attributes and Methods

    def getCurrentSpeller():
        """
        Returns the name of the current speller; this is synomonous with the
        name of the binary program
        """

    def getSpellPath():
        """
        Returns the path to the binary of the speller
        """

    def getSpellDictSw():
        """
        Returns the current switch setting for using a specific dictionary
        If this is None, no dictionary will be specified so the spellers
        default (or configured) dictionary will be used
        """

    def getSpellDict():
        """
        Returns the currently defined dictionary name
        """

    def getSpellDicts():
        """
        Returns an ordered list of available dictionary names
        --
        We do not know which dictionaries have been installed
        so SysMan should edited list available in the speller defs module
        """

    def getSpellLanguageSw():
        """
        Returns the control switch used to specify the language
        used by the speller; the dictionary should already have been installed.
        If no switch is defined, the speller will just use its internal
        notion of a which language to use - some spellers allow this to be
        controlled through a .conf file
        """

    def getSpellLanguage():
        """
        Returns the currently defined language
        """

    def getSpellLanguages():
        """
        Returns an ordered list available languages
        --
        We do not know which languages have been installed
        so SysMan should edited list available in the speller defs module
        """

    def getSpellEncodingSw():
        """
        Returns the current switch for specifying an encoding
        If this is None, no encoding will be specified
        """

    def getSpellEncoding():
        """
        Returns the current encoding
        """

    def getSpellEncodings():
        """
        Returns an unordered list of available encodings
        --
        We do not know which encodings are available
        so SysMan should edit list available in the speller defs module
        """

    def getSpellSwitches():
        """
        Returns current settings for additional switches
        """

    def getSpellWordlistSw():
        """
        Returns the switch for loading an extra wordlist
        """

    def getSpellWordlist():
        """
        Returns a wordlist; a list of words to be used as
        a supplement to the spellers standard dictionary
        The speller will get this data delivered as a file (from the
        FileSystem) so this method returns the actual words
        for editing perhaps
        """

    def getSpellCommand():
        """
        Build the speller command to be called from all the data
        we have been told about; if switches are not specified,
        functions will not be activated.
        """

class ISpellCheckUtility:
    """
    SpellCheckUtility class - this boy actually does the spelling thing
    """

    def getTypeTest(self):
        """
        Returns pass or failure of type test
        We just pretend to check content types we don't know how to deal with
        Test this value to determine if a real spell check was done
        """

    def getMisspelledInfo():
        """
        Returns a list of misspelled words, where each occurs and suggested
        corrections (if any)
        """

    def getLines():
        """
        Returns the text broken into individual lines
        """

    def highlightWordInContext(text, word, offset):
        """
        Returns a line of text containing the word to be corrected
        with the word highlighted visually
        Returned as a list
        """

class ISpellingMistake:
    """
    A spelling mistake object giving access to appropriate attributes
    provided by a spell checker
    """

    def misspelled_word(self):
        """
        The word identified as being misspelled
        """

    def escaped_word(self):
        """
        The word identified as being misspelled escaped
        """

    def line(self):
        """
        The line in text body where the bad word occurs
        Numbered in sequence from the start of the text (0)
        """

    def offset(self):
        """
        A character offest in the line where the word occurs;
        provided by the speller
        """

    def values(self):
        """
        A list of possible replacements words as suggested by the speller
        """

class PipeCommand:
    """
    Wrapper for Unix/Windows implementations of Pipe Class

    A class for creating and utilising a pipe
    """

    def getCommand(self):
        """
        Returns the command used to open the pipe
        """

    def pumpData(self,data):
        """
        Pump data down the pipe
        """

    def pumpDone(self):
        """
        All input has been completed
        """

    def suckData(self):
        """
        Suck data out of the pipe
        """

    def suckDone(self):
        """
        All output has been recovered
        """

    def status(self):
        """
        Returns the current status of the command
        See popen2 module docs for info
        """

    def errors(self):
        """
        If errors have been trapped, then return them all
        """

    def close(self):
        """
        Controlled exit
        Same as __del__
        """
