
      # -*- coding: latin1 -*-

"""
Set defaults for initialising a speller
These are used when a speller is chosen, they can be over-ridden
for each instance

- speller
  name of the binary to call

- binpath
  path to the binary

- language
  default language from the list below

- languages
  list of valid languages the speller knows about
  this is system dependent, what wordlist have been installed?
  this can be set as none if there is no choice

- languagesw
  the switch the command uses for setting the language
  if this is empty, no language will be specified

- encoding
  the default char-encoding from the following list

- encodings
  list of encodings the speller understands
  this can be set as none if there is no choice
  switch to set the encoding

- encodingsw
  switch used to set the encoding
  if this is empty, no encoding will be attempted

- pipesw
  the switch setting the speller into pipe mode

- switches
  other default switches used, these are additional
  to swicthes defined here

- canreload
  True/False whether a personal wordlist can be read
  back by the speller

- wordlistsw
  switch used to specifiy an included wordlist

"""
# Defaults for ispell
#
# ispell does not have encoding or language switching capabilities
#
# Sorry, the dictionary names are unlikely to be correct
#
# Check the behaviour of ispell in looking for dictionaries
# (main and personal) in various locations by default
#
# ispell Issues
#
# 0. None known

defs = {
   'speller': 'ispell',
   'binpath': '/usr/bin',
   'dict': 'english',
   'dicts': {
     'afrikaans': 'Afrikaans',
     'albanian': 'Albanian',
     'belarusian': 'Belarusian',
     'bg': 'Bulgarian',
     'catalan': 'Catalan',
     'croatian': 'Croatian',
     'czech': 'Czech',
     'danish': 'Danish',
     'dutch': 'Dutch',
     'english': 'English',
     'esperanto': 'Esperanto',
     'estonian': 'Estonian',
     'finnish': 'Finnish',
     'french': 'French',
     'galician': 'Galician (Minimos)',
     'german': 'German',
     'greek': 'Greek',
     'hebrew': 'Hebrew',
     'hungarian': 'Hungarian',
     'interlingua': 'Interlingua',
     'italian': 'Italian',
     'irish': 'Irish',
     'latin': 'Latin',
     'lithuanian': 'Lithuanian',
     'minimos': 'Minimos',
     'maltese': 'Maltese',
     'norwegian': 'Norwegian',
     'polish': 'Polish',
     'portuguese': 'Português',
     'romanian': 'Romanian',
     'russian': 'Russian',
     'slovakian': 'Slovakian',
     'slovenian': 'Slovenian',
     'sorbian': 'Sorbian',
     'spanish': 'Spanish',
     'swedish': 'Swedish',
     'ukrainian': 'Ukrainian',
     'walloon': 'Walloon'
   },
   'dictsw': '-d ',
   'language': 'en',
   'languages': (),
   'languagesw': '',
   'encoding': 'utf-8',
   'encodings': ('utf-8','iso-5678'),
   'encodingsw': '',
   'pipesw': '-a',
   'switches': '-H', # sets HTML mode
   'canreload': None,
   'wordlistsw': '-p',
}
